@@ -7,8 +7,8 @@ __author__ = 'https://github.com/akvilary'
 
 import uuid
 
-from sqlconstructor.abstracts.string_convertible import StringConvertible
-from sqlconstructor.abstracts.special_json_convertible import SpecialJsonConvertible
+from sqlconstructor.utils.classes.string_convertible import StringConvertible
+from sqlconstructor.utils.classes.special_convertion_requier import SpecialConvertionRequier
 from . import to_sql_string
 from . import to_array
 from . import to_json
@@ -18,8 +18,8 @@ def convert_any_to_sql(value) -> str:
     """Convert any value to sql representation"""
     if isinstance(value, str):
         return to_sql_string.convert_python_str_to_sql_str(value)
-    if isinstance(value, SpecialJsonConvertible):
-        return value.__json_str__()
+    if isinstance(value, SpecialConvertionRequier):
+        return value.__as_sql__()
     if isinstance(value, StringConvertible):
         return str(value)
     if isinstance(value, (list, set, tuple)):
