@@ -1,29 +1,31 @@
 # coding=utf-8
 """
-Module of Values class.
+Module of SqlVals class.
 """
 
 __author__ = 'https://github.com/akvilary'
 
 from typing import Iterable
 
-from .helpers import converters
 from .sql_container import SqlContainer
 from .sql_enum import SqlEnum
+from .sql_val import SqlVal
+from .utils.classes.string_convertible import StringConvertible
+from .utils.classes.special_convertion_requier import SpecialConvertionRequier
 
 
-class SqlVals(SqlEnum):
+class SqlVals(SqlEnum, StringConvertible, SpecialConvertionRequier):
     """
-    Values class is invented for better experience to enumerate values.
-    It is possible to register cte and fill it after.
-    Or you could add filled query as cte instantly.
-    Now it is your choice!
+    SqlVals class is invented for better experience to convert python values to sql strings.
     """
 
-    def __repr__(self) -> str:
+    def __str__(self) -> str:
         """Convert SqlContainer instance to str"""
         return str(self.multiline().wrap())
 
+    def __json_str__(self) -> str:
+        return str(self.inline())
+
     def inline(self) -> SqlContainer:
         """Get inline representation"""
         return SqlContainer(', '.join(get_values(self)))
@@ -32,7 +34,10 @@ class SqlVals(SqlEnum):
         """Get multiline representation"""
         return SqlContainer(',\n'.join(get_values(self)))
 
+    def copy(self, /):
+        return SqlVals(list(self.list))
+
 
 def get_values(iterable: Iterable):
     """Get values iterator"""
-    return (converters.convert_any_to_sql(x) for x in iterable)
+    return (str(SqlVal(x)) for x in iterable)
