@@ -4,9 +4,9 @@ from sqlconstructor import SqlVal
 
 @pytest.mark.SqlVal
 def test_add():
-    assert (SqlVal('Best') + " or 'Medium'") == "'Best' or 'Medium'"
+    assert SqlVal('a') + 'b'== "'a'b"
 
 
 @pytest.mark.SqlVal
 def test_radd():
-    assert ('quality=' + SqlVal('Best')) == "quality='Best'"
+    assert ('b' + SqlVal('a')) == "b'a'"
